@@ -17,14 +17,26 @@ from tornado.ioloop import IOLoop
 from tornado.locks import Event
 
 from .compatibility import get_thread_identity
-from .comm import (connect, listen, CommClosedError,
-                   normalize_address,
-                   unparse_host_port, get_address_host_port)
+from .comm import (
+    connect,
+    listen,
+    CommClosedError,
+    normalize_address,
+    unparse_host_port,
+    get_address_host_port,
+)
 from .metrics import time
 from . import profile
 from .system_monitor import SystemMonitor
-from .utils import (get_traceback, truncate_exception, ignoring, shutting_down,
-                    PeriodicCallback, parse_timedelta, has_keyword)
+from .utils import (
+    get_traceback,
+    truncate_exception,
+    ignoring,
+    shutting_down,
+    PeriodicCallback,
+    parse_timedelta,
+    has_keyword,
+)
 from . import protocol
 
 
@@ -38,6 +50,7 @@ logger = logging.getLogger(__name__)
 def get_total_physical_memory():
     try:
         import psutil
+
         return psutil.virtual_memory().total / 2
     except ImportError:
         return 2e9
@@ -46,14 +59,17 @@ def get_total_physical_memory():
 def raise_later(exc):
     def _raise(*args, **kwargs):
         raise exc
+
     return _raise
 
 
 MAX_BUFFER_SIZE = get_total_physical_memory()
 
-tick_maximum_delay = parse_timedelta(dask.config.get('distributed.admin.tick.limit'), default='ms')
+tick_maximum_delay = parse_timedelta(
+    dask.config.get("distributed.admin.tick.limit"), default="ms"
+)
 
-LOG_PDB = dask.config.get('distributed.admin.pdb-on-err')
+LOG_PDB = dask.config.get("distributed.admin.pdb-on-err")
 
 
 class Server(object):
@@ -92,23 +108,33 @@ class Server(object):
     *  ``{'op': 'add', 'x': 10, 'y': 20}``
 
     """
-    default_ip = ''
+
+    default_ip = ""
     default_port = 0
 
-    def __init__(self, handlers, blocked_handlers=None, stream_handlers=None, connection_limit=512,
-                 deserialize=True, io_loop=None):
+    def __init__(
+        self,
+        handlers,
+        blocked_handlers=None,
+        stream_handlers=None,
+        connection_limit=512,
+        deserialize=True,
+        io_loop=None,
+    ):
         self.handlers = {
-            'identity': self.identity,
-            'connection_stream': self.handle_stream,
+            "identity": self.identity,
+            "connection_stream": self.handle_stream,
         }
         self.handlers.update(handlers)
         if blocked_handlers is None:
-            blocked_handlers = dask.config.get('distributed.%s.blocked-handlers' % type(self).__name__.lower(), [])
+            blocked_handlers = dask.config.get(
+                "distributed.%s.blocked-handlers" % type(self).__name__.lower(), []
+            )
         self.blocked_handlers = blocked_handlers
         self.stream_handlers = {}
         self.stream_handlers.update(stream_handlers or {})
 
-        self.id = type(self).__name__ + '-' + str(uuid.uuid4())
+        self.id = type(self).__name__ + "-" + str(uuid.uuid4())
         self._address = None
         self._listen_address = None
         self._port = None
@@ -125,31 +151,36 @@ class Server(object):
         self.io_loop = io_loop or IOLoop.current()
         self.loop = self.io_loop
 
-        if not hasattr(self.io_loop, 'profile'):
+        if not hasattr(self.io_loop, "profile"):
             ref = weakref.ref(self.io_loop)
 
-            if hasattr(self.io_loop, 'closing'):
+            if hasattr(self.io_loop, "closing"):
+
                 def stop():
                     loop = ref()
                     return loop is None or loop.closing
+
             else:
+
                 def stop():
                     loop = ref()
                     return loop is None or loop._closing
 
             self.io_loop.profile = profile.watch(
-                    omit=('profile.py', 'selectors.py'),
-                    interval=dask.config.get('distributed.worker.profile.interval'),
-                    cycle=dask.config.get('distributed.worker.profile.cycle'),
-                    stop=stop,
+                omit=("profile.py", "selectors.py"),
+                interval=dask.config.get("distributed.worker.profile.interval"),
+                cycle=dask.config.get("distributed.worker.profile.cycle"),
+                stop=stop,
             )
 
         # Statistics counters for various events
         with ignoring(ImportError):
             from .counter import Digest
+
             self.digests = defaultdict(partial(Digest, loop=self.io_loop))
 
         from .counter import Counter
+
         self.counters = defaultdict(partial(Counter, loop=self.io_loop))
         self.events = defaultdict(lambda: deque(maxlen=10000))
         self.event_counts = defaultdict(lambda: 0)
@@ -157,15 +188,18 @@ class Server(object):
         self.periodic_callbacks = dict()
 
         pc = PeriodicCallback(self.monitor.update, 500, io_loop=self.io_loop)
-        self.periodic_callbacks['monitor'] = pc
+        self.periodic_callbacks["monitor"] = pc
 
         self._last_tick = time()
         pc = PeriodicCallback(
-                self._measure_tick,
-                parse_timedelta(dask.config.get('distributed.admin.tick.interval'), default='ms') * 1000,
-                io_loop=self.io_loop
+            self._measure_tick,
+            parse_timedelta(
+                dask.config.get("distributed.admin.tick.interval"), default="ms"
+            )
+            * 1000,
+            io_loop=self.io_loop,
         )
-        self.periodic_callbacks['tick'] = pc
+        self.periodic_callbacks["tick"] = pc
 
         self.thread_id = 0
 
@@ -189,6 +223,7 @@ class Server(object):
             for pc in self.periodic_callbacks.values():
                 if not pc.is_running():
                     pc.start()
+
         self.io_loop.add_callback(start_pcs)
 
     def stop(self):
@@ -209,16 +244,19 @@ class Server(object):
         diff = now - self._last_tick
         self._last_tick = now
         if diff > tick_maximum_delay:
-            logger.info("Event loop was unresponsive in %s for %.2fs.  "
-                        "This is often caused by long-running GIL-holding "
-                        "functions or moving large chunks of data. "
-                        "This can cause timeouts and instability.",
-                        type(self).__name__, diff)
+            logger.info(
+                "Event loop was unresponsive in %s for %.2fs.  "
+                "This is often caused by long-running GIL-holding "
+                "functions or moving large chunks of data. "
+                "This can cause timeouts and instability.",
+                type(self).__name__,
+                diff,
+            )
         if self.digests is not None:
-            self.digests['tick-duration'].add(diff)
+            self.digests["tick-duration"].add(diff)
 
     def log_event(self, name, msg):
-        msg['time'] = time()
+        msg["time"] = time()
         if isinstance(name, list):
             for n in name:
                 self.events[n].append(msg)
@@ -263,7 +301,7 @@ class Server(object):
         return self._port
 
     def identity(self, comm=None):
-        return {'type': type(self).__name__, 'id': self.id}
+        return {"type": type(self).__name__, "id": self.id}
 
     def listen(self, port_or_addr=None, listen_args=None):
         if port_or_addr is None:
@@ -275,9 +313,12 @@ class Server(object):
         else:
             addr = port_or_addr
             assert isinstance(addr, string_types)
-        self.listener = listen(addr, self.handle_comm,
-                               deserialize=self.deserialize,
-                               connection_args=listen_args)
+        self.listener = listen(
+            addr,
+            self.handle_comm,
+            deserialize=self.deserialize,
+            connection_args=listen_args,
+        )
         self.listener.start()
 
     @gen.coroutine
@@ -307,51 +348,61 @@ class Server(object):
                     logger.debug("Message from %r: %s", address, msg)
                 except EnvironmentError as e:
                     if not shutting_down():
-                        logger.debug("Lost connection to %r while reading message: %s."
-                                     " Last operation: %s",
-                                     address, e, op)
+                        logger.debug(
+                            "Lost connection to %r while reading message: %s."
+                            " Last operation: %s",
+                            address,
+                            e,
+                            op,
+                        )
                     break
                 except Exception as e:
                     logger.exception(e)
-                    yield comm.write(error_message(e, status='uncaught-error'))
+                    yield comm.write(error_message(e, status="uncaught-error"))
                     continue
                 if not isinstance(msg, dict):
-                    raise TypeError("Bad message type.  Expected dict, got\n  "
-                                    + str(msg))
+                    raise TypeError(
+                        "Bad message type.  Expected dict, got\n  " + str(msg)
+                    )
 
                 try:
-                    op = msg.pop('op')
+                    op = msg.pop("op")
                 except KeyError:
                     raise ValueError(
-                        "Received unexpected message without 'op' key: " %
-                        str(msg)
+                        "Received unexpected message without 'op' key: " % str(msg)
                     )
                 if self.counters is not None:
-                    self.counters['op'].add(op)
+                    self.counters["op"].add(op)
                 self._comms[comm] = op
-                serializers = msg.pop('serializers', None)
-                close_desired = msg.pop('close', False)
-                reply = msg.pop('reply', True)
-                if op == 'close':
+                serializers = msg.pop("serializers", None)
+                close_desired = msg.pop("close", False)
+                reply = msg.pop("reply", True)
+                if op == "close":
                     if reply:
-                        yield comm.write('OK')
+                        yield comm.write("OK")
                     break
 
                 result = None
                 try:
                     if op in self.blocked_handlers:
-                        _msg = ("The '{op}' handler has been explicitly disallowed "
-                                "in {obj}, possibly due to security concerns.")
+                        _msg = (
+                            "The '{op}' handler has been explicitly disallowed "
+                            "in {obj}, possibly due to security concerns."
+                        )
                         exc = ValueError(_msg.format(op=op, obj=type(self).__name__))
                         handler = raise_later(exc)
                     else:
                         handler = self.handlers[op]
                 except KeyError:
-                    logger.warning("No handler %s found in %s", op,
-                                   type(self).__name__, exc_info=True)
+                    logger.warning(
+                        "No handler %s found in %s",
+                        op,
+                        type(self).__name__,
+                        exc_info=True,
+                    )
                 else:
-                    if serializers is not None and has_keyword(handler, 'serializers'):
-                        msg['serializers'] = serializers  # add back in
+                    if serializers is not None and has_keyword(handler, "serializers"):
+                        msg["serializers"] = serializers  # add back in
 
                     logger.debug("Calling into handler %s", handler.__name__)
                     try:
@@ -360,19 +411,23 @@ class Server(object):
                             self._ongoing_coroutines.add(result)
                             result = yield result
                     except (CommClosedError, CancelledError) as e:
-                        if self.status == 'running':
+                        if self.status == "running":
                             logger.info("Lost connection to %r: %s", address, e)
                         break
                     except Exception as e:
                         logger.exception(e)
-                        result = error_message(e, status='uncaught-error')
+                        result = error_message(e, status="uncaught-error")
 
-                if reply and result != 'dont-reply':
+                if reply and result != "dont-reply":
                     try:
                         yield comm.write(result, serializers=serializers)
                     except (EnvironmentError, TypeError) as e:
-                        logger.debug("Lost connection to %r while sending result for op %r: %s",
-                                     address, op, e)
+                        logger.debug(
+                            "Lost connection to %r while sending result for op %r: %s",
+                            address,
+                            op,
+                            e,
+                        )
                         break
                 msg = result = None
                 if close_desired:
@@ -386,8 +441,9 @@ class Server(object):
                 try:
                     comm.abort()
                 except Exception as e:
-                    logger.error("Failed while closing connection to %r: %s",
-                                 address, e)
+                    logger.error(
+                        "Failed while closing connection to %r: %s", address, e
+                    )
 
     @gen.coroutine
     def handle_stream(self, comm, extra=None, every_cycle=[]):
@@ -404,11 +460,11 @@ class Server(object):
 
                 if not comm.closed():
                     for msg in msgs:
-                        if msg == 'OK':  # from close
+                        if msg == "OK":  # from close
                             break
-                        op = msg.pop('op')
+                        op = msg.pop("op")
                         if op:
-                            if op == 'close-stream':
+                            if op == "close-stream":
                                 closed = True
                                 break
                             handler = self.stream_handlers[op]
@@ -424,6 +480,7 @@ class Server(object):
             logger.exception(e)
             if LOG_PDB:
                 import pdb
+
                 pdb.set_trace()
             raise
         finally:
@@ -445,12 +502,11 @@ class Server(object):
 
 
 def pingpong(comm):
-    return b'pong'
+    return b"pong"
 
 
 @gen.coroutine
-def send_recv(comm, reply=True, serializers=None, deserializers=None,
-              **kwargs):
+def send_recv(comm, reply=True, serializers=None, deserializers=None, **kwargs):
     """ Send and recv with a Comm.
 
     Keyword arguments turn into the message
@@ -458,16 +514,16 @@ def send_recv(comm, reply=True, serializers=None, deserializers=None,
     response = yield send_recv(comm, op='ping', reply=True)
     """
     msg = kwargs
-    msg['reply'] = reply
-    please_close = kwargs.get('close')
+    msg["reply"] = reply
+    please_close = kwargs.get("close")
     force_close = False
     if deserializers is None:
         deserializers = serializers
     if deserializers is not None:
-        msg['serializers'] = deserializers
+        msg["serializers"] = deserializers
 
     try:
-        yield comm.write(msg, serializers=serializers, on_error='raise')
+        yield comm.write(msg, serializers=serializers, on_error="raise")
         if reply:
             response = yield comm.read(deserializers=deserializers)
         else:
@@ -482,11 +538,11 @@ def send_recv(comm, reply=True, serializers=None, deserializers=None,
         elif force_close:
             comm.abort()
 
-    if isinstance(response, dict) and response.get('status') == 'uncaught-error':
+    if isinstance(response, dict) and response.get("status") == "uncaught-error":
         if comm.deserialize:
             six.reraise(*clean_exception(**response))
         else:
-            raise Exception(response['text'])
+            raise Exception(response["text"])
     raise gen.Return(response)
 
 
@@ -514,16 +570,25 @@ class rpc(object):
 
     >>> remote.close_comms()  # doctest: +SKIP
     """
+
     active = weakref.WeakSet()
     comms = ()
     address = None
 
-    def __init__(self, arg=None, comm=None, deserialize=True, timeout=None,
-                 connection_args=None, serializers=None, deserializers=None):
+    def __init__(
+        self,
+        arg=None,
+        comm=None,
+        deserialize=True,
+        timeout=None,
+        connection_args=None,
+        serializers=None,
+        deserializers=None,
+    ):
         self.comms = {}
         self.address = coerce_to_address(arg)
         self.timeout = timeout
-        self.status = 'running'
+        self.status = "running"
         self.deserialize = deserialize
         self.serializers = serializers
         self.deserializers = deserializers if deserializers is not None else serializers
@@ -549,7 +614,7 @@ class rpc(object):
 
         As is done in __getattr__ below.
         """
-        if self.status == 'closed':
+        if self.status == "closed":
             raise RPCClosed("RPC Closed")
         to_clear = set()
         open = False
@@ -561,19 +626,21 @@ class rpc(object):
         for s in to_clear:
             del self.comms[s]
         if not open or comm.closed():
-            comm = yield connect(self.address, self.timeout,
-                                 deserialize=self.deserialize,
-                                 connection_args=self.connection_args)
-        self.comms[comm] = False     # mark as taken
+            comm = yield connect(
+                self.address,
+                self.timeout,
+                deserialize=self.deserialize,
+                connection_args=self.connection_args,
+            )
+        self.comms[comm] = False  # mark as taken
         raise gen.Return(comm)
 
     def close_comms(self):
-
         @gen.coroutine
         def _close_comm(comm):
             # Make sure we tell the peer to close
             try:
-                yield comm.write({'op': 'close', 'reply': False})
+                yield comm.write({"op": "close", "reply": False})
                 yield comm.close()
             except EnvironmentError:
                 comm.abort()
@@ -586,25 +653,27 @@ class rpc(object):
     def __getattr__(self, key):
         @gen.coroutine
         def send_recv_from_rpc(**kwargs):
-            if self.serializers is not None and kwargs.get('serializers') is None:
-                kwargs['serializers'] = self.serializers
-            if self.deserializers is not None and kwargs.get('deserializers') is None:
-                kwargs['deserializers'] = self.deserializers
+            if self.serializers is not None and kwargs.get("serializers") is None:
+                kwargs["serializers"] = self.serializers
+            if self.deserializers is not None and kwargs.get("deserializers") is None:
+                kwargs["deserializers"] = self.deserializers
             try:
                 comm = yield self.live_comm()
                 result = yield send_recv(comm=comm, op=key, **kwargs)
             except (RPCClosed, CommClosedError) as e:
-                raise e.__class__("%s: while trying to call remote method %r"
-                                  % (e, key,))
+                raise e.__class__(
+                    "%s: while trying to call remote method %r" % (e, key)
+                )
 
             self.comms[comm] = True  # mark as open
             raise gen.Return(result)
+
         return send_recv_from_rpc
 
     def close_rpc(self):
-        if self.status != 'closed':
+        if self.status != "closed":
             rpc.active.discard(self)
-        self.status = 'closed'
+        self.status = "closed"
         self.close_comms()
 
     def __enter__(self):
@@ -614,13 +683,14 @@ class rpc(object):
         self.close_rpc()
 
     def __del__(self):
-        if self.status != 'closed':
+        if self.status != "closed":
             rpc.active.discard(self)
-            self.status = 'closed'
+            self.status = "closed"
             still_open = [comm for comm in self.comms if not comm.closed()]
             if still_open:
-                logger.warning("rpc object %s deleted with %d open comms",
-                               self, len(still_open))
+                logger.warning(
+                    "rpc object %s deleted with %d open comms", self, len(still_open)
+                )
                 for comm in still_open:
                     comm.abort()
 
@@ -648,10 +718,10 @@ class PooledRPCCall(object):
     def __getattr__(self, key):
         @gen.coroutine
         def send_recv_from_rpc(**kwargs):
-            if self.serializers is not None and kwargs.get('serializers') is None:
-                kwargs['serializers'] = self.serializers
-            if self.deserializers is not None and kwargs.get('deserializers') is None:
-                kwargs['deserializers'] = self.deserializers
+            if self.serializers is not None and kwargs.get("serializers") is None:
+                kwargs["serializers"] = self.serializers
+            if self.deserializers is not None and kwargs.get("deserializers") is None:
+                kwargs["deserializers"] = self.deserializers
             comm = yield self.pool.connect(self.addr)
             try:
                 result = yield send_recv(comm=comm, op=key, **kwargs)
@@ -659,6 +729,7 @@ class PooledRPCCall(object):
                 self.pool.reuse(self.addr, comm)
 
             raise gen.Return(result)
+
         return send_recv_from_rpc
 
     def close_rpc(self):
@@ -709,12 +780,15 @@ class ConnectionPool(object):
         Whether or not to deserialize data by default or pass it through
     """
 
-    def __init__(self, limit=512,
-                 deserialize=True,
-                 serializers=None,
-                 deserializers=None,
-                 connection_args=None):
-        self.limit = limit     # Max number of open comms
+    def __init__(
+        self,
+        limit=512,
+        deserialize=True,
+        serializers=None,
+        deserializers=None,
+        connection_args=None,
+    ):
+        self.limit = limit  # Max number of open comms
         # Invariant: len(available) == open - active
         self.available = defaultdict(set)
         # Invariant: len(occupied) == active
@@ -734,15 +808,14 @@ class ConnectionPool(object):
         return self.active + sum(map(len, self.available.values()))
 
     def __repr__(self):
-        return "<ConnectionPool: open=%d, active=%d>" % (self.open,
-                                                         self.active)
+        return "<ConnectionPool: open=%d, active=%d>" % (self.open, self.active)
 
     def __call__(self, addr=None, ip=None, port=None):
         """ Cached rpc objects """
         addr = addr_from_args(addr=addr, ip=ip, port=port)
-        return PooledRPCCall(addr, self,
-                             serializers=self.serializers,
-                             deserializers=self.deserializers)
+        return PooledRPCCall(
+            addr, self, serializers=self.serializers, deserializers=self.deserializers
+        )
 
     @gen.coroutine
     def connect(self, addr, timeout=None):
@@ -763,9 +836,12 @@ class ConnectionPool(object):
             yield self.event.wait()
 
         try:
-            comm = yield connect(addr, timeout=timeout,
-                                 deserialize=self.deserialize,
-                                 connection_args=self.connection_args)
+            comm = yield connect(
+                addr,
+                timeout=timeout,
+                deserialize=self.deserialize,
+                connection_args=self.connection_args,
+            )
         except Exception:
             raise
         occupied.add(comm)
@@ -794,8 +870,9 @@ class ConnectionPool(object):
         """
         Collect open but unused communications, to allow opening other ones.
         """
-        logger.info("Collecting unused comms.  open: %d, active: %d",
-                    self.open, self.active)
+        logger.info(
+            "Collecting unused comms.  open: %d, active: %d", self.open, self.active
+        )
         for addr, comms in self.available.items():
             for comm in comms:
                 comm.close()
@@ -838,7 +915,7 @@ def coerce_to_address(o):
     return normalize_address(o)
 
 
-def error_message(e, status='error'):
+def error_message(e, status="error"):
     """ Produce message to send back given an exception has occurred
 
     This does the following:
@@ -865,17 +942,14 @@ def error_message(e, status='error'):
     try:
         tb2 = protocol.pickle.dumps(tb)
     except Exception:
-        tb = tb2 = ''.join(traceback.format_tb(tb))
+        tb = tb2 = "".join(traceback.format_tb(tb))
 
     if len(tb2) > 10000:
         tb_result = None
     else:
         tb_result = protocol.to_serialize(tb)
 
-    return {'status': status,
-            'exception': e4,
-            'traceback': tb_result,
-            'text': str(e2)}
+    return {"status": status, "exception": e4, "traceback": tb_result, "text": str(e2)}
 
 
 def clean_exception(exception, traceback, **kwargs):
