@@ -16,12 +16,16 @@ import pytest
 from distributed import Client, Worker, Nanny
 from distributed.deploy.local import LocalCluster, nprocesses_nthreads
 from distributed.metrics import time
-from distributed.utils_test import (inc, gen_test, slowinc,
-                                    assert_cannot_connect,
-                                    assert_can_connect_locally_4,
-                                    assert_can_connect_from_everywhere_4,
-                                    assert_can_connect_from_everywhere_4_6,
-                                    captured_logger)
+from distributed.utils_test import (
+    inc,
+    gen_test,
+    slowinc,
+    assert_cannot_connect,
+    assert_can_connect_locally_4,
+    assert_can_connect_from_everywhere_4,
+    assert_can_connect_from_everywhere_4_6,
+    captured_logger,
+)
 from distributed.utils_test import loop  # noqa: F401
 from distributed.utils import sync
 from distributed.worker import TOTAL_MEMORY
@@ -30,8 +34,14 @@ from distributed.deploy.utils_test import ClusterTest
 
 
 def test_simple(loop):
-    with LocalCluster(4, scheduler_port=0, processes=False, silence_logs=False,
-                      dashboard_address=None, loop=loop) as c:
+    with LocalCluster(
+        4,
+        scheduler_port=0,
+        processes=False,
+        silence_logs=False,
+        dashboard_address=None,
+        loop=loop,
+    ) as c:
         with Client(c) as e:
             x = e.submit(inc, 1)
             x.result()
@@ -42,21 +52,23 @@ def test_simple(loop):
 
 
 def test_local_cluster_supports_blocked_handlers(loop):
-    with LocalCluster(blocked_handlers=['run_function'], loop=loop) as c:
+    with LocalCluster(blocked_handlers=["run_function"], loop=loop) as c:
         with Client(c) as client:
             with pytest.raises(ValueError) as exc:
                 client.run_on_scheduler(lambda x: x, 42)
 
-    assert "'run_function' handler has been explicitly disallowed in Scheduler" in str(exc.value)
+    assert "'run_function' handler has been explicitly disallowed in Scheduler" in str(
+        exc.value
+    )
 
 
-@pytest.mark.skipif('sys.version_info[0] == 2', reason='fork issues')
+@pytest.mark.skipif("sys.version_info[0] == 2", reason="fork issues")
 def test_close_twice():
     with LocalCluster() as cluster:
         with Client(cluster.scheduler_address) as client:
             f = client.map(inc, range(100))
             client.gather(f)
-        with captured_logger('tornado.application') as log:
+        with captured_logger("tornado.application") as log:
             cluster.close()
             cluster.close()
             sleep(0.5)
@@ -64,10 +76,16 @@ def test_close_twice():
         assert not log
 
 
-@pytest.mark.skipif('sys.version_info[0] == 2', reason='multi-loop')
+@pytest.mark.skipif("sys.version_info[0] == 2", reason="multi-loop")
 def test_procs():
-    with LocalCluster(2, scheduler_port=0, processes=False, threads_per_worker=3,
-                      dashboard_address=None, silence_logs=False) as c:
+    with LocalCluster(
+        2,
+        scheduler_port=0,
+        processes=False,
+        threads_per_worker=3,
+        dashboard_address=None,
+        silence_logs=False,
+    ) as c:
         assert len(c.workers) == 2
         assert all(isinstance(w, Worker) for w in c.workers)
         with Client(c.scheduler.address) as e:
@@ -75,8 +93,14 @@ def test_procs():
             assert all(isinstance(w, Worker) for w in c.workers)
         repr(c)
 
-    with LocalCluster(2, scheduler_port=0, processes=True, threads_per_worker=3,
-                      dashboard_address=None, silence_logs=False) as c:
+    with LocalCluster(
+        2,
+        scheduler_port=0,
+        processes=True,
+        threads_per_worker=3,
+        dashboard_address=None,
+        silence_logs=False,
+    ) as c:
         assert len(c.workers) == 2
         assert all(isinstance(w, Nanny) for w in c.workers)
         with Client(c.scheduler.address) as e:
@@ -92,10 +116,11 @@ def test_move_unserializable_data():
     Test that unserializable data is still fine to transfer over inproc
     transports.
     """
-    with LocalCluster(processes=False, silence_logs=False,
-                      dashboard_address=None) as cluster:
-        assert cluster.scheduler_address.startswith('inproc://')
-        assert cluster.workers[0].address.startswith('inproc://')
+    with LocalCluster(
+        processes=False, silence_logs=False, dashboard_address=None
+    ) as cluster:
+        assert cluster.scheduler_address.startswith("inproc://")
+        assert cluster.workers[0].address.startswith("inproc://")
         with Client(cluster) as client:
             lock = Lock()
             x = client.scatter(lock)
@@ -107,41 +132,49 @@ def test_transports():
     """
     Test the transport chosen by LocalCluster depending on arguments.
     """
-    with LocalCluster(1, processes=False, silence_logs=False,
-                      dashboard_address=None) as c:
-        assert c.scheduler_address.startswith('inproc://')
-        assert c.workers[0].address.startswith('inproc://')
+    with LocalCluster(
+        1, processes=False, silence_logs=False, dashboard_address=None
+    ) as c:
+        assert c.scheduler_address.startswith("inproc://")
+        assert c.workers[0].address.startswith("inproc://")
         with Client(c.scheduler.address) as e:
             assert e.submit(inc, 4).result() == 5
 
     # Have nannies => need TCP
-    with LocalCluster(1, processes=True, silence_logs=False,
-                      dashboard_address=None) as c:
-        assert c.scheduler_address.startswith('tcp://')
-        assert c.workers[0].address.startswith('tcp://')
+    with LocalCluster(
+        1, processes=True, silence_logs=False, dashboard_address=None
+    ) as c:
+        assert c.scheduler_address.startswith("tcp://")
+        assert c.workers[0].address.startswith("tcp://")
         with Client(c.scheduler.address) as e:
             assert e.submit(inc, 4).result() == 5
 
     # Scheduler port specified => need TCP
-    with LocalCluster(1, processes=False, scheduler_port=8786, silence_logs=False,
-                      dashboard_address=None) as c:
+    with LocalCluster(
+        1,
+        processes=False,
+        scheduler_port=8786,
+        silence_logs=False,
+        dashboard_address=None,
+    ) as c:
 
-        assert c.scheduler_address == 'tcp://127.0.0.1:8786'
-        assert c.workers[0].address.startswith('tcp://')
+        assert c.scheduler_address == "tcp://127.0.0.1:8786"
+        assert c.workers[0].address.startswith("tcp://")
         with Client(c.scheduler.address) as e:
             assert e.submit(inc, 4).result() == 5
 
 
-@pytest.mark.skipif('sys.version_info[0] == 2', reason='')
+@pytest.mark.skipif("sys.version_info[0] == 2", reason="")
 class LocalTest(ClusterTest, unittest.TestCase):
     Cluster = partial(LocalCluster, silence_logs=False, dashboard_address=None)
-    kwargs = {'dashboard_address': None}
+    kwargs = {"dashboard_address": None}
 
 
-@pytest.mark.skipif('sys.version_info[0] == 2', reason='')
+@pytest.mark.skipif("sys.version_info[0] == 2", reason="")
 def test_Client_with_local(loop):
-    with LocalCluster(1, scheduler_port=0, silence_logs=False,
-                      dashboard_address=None, loop=loop) as c:
+    with LocalCluster(
+        1, scheduler_port=0, silence_logs=False, dashboard_address=None, loop=loop
+    ) as c:
         with Client(c) as e:
             assert len(e.ncores()) == len(c.workers)
             assert c.scheduler_address in repr(c)
@@ -150,22 +183,26 @@ def test_Client_with_local(loop):
 def test_Client_solo(loop):
     with Client(loop=loop, silence_logs=False) as c:
         pass
-    assert c.cluster.status == 'closed'
+    assert c.cluster.status == "closed"
 
 
 @gen_test()
 def test_duplicate_clients():
-    pytest.importorskip('bokeh')
+    pytest.importorskip("bokeh")
     c1 = yield Client(processes=False, silence_logs=False, dashboard_address=9876)
     with pytest.warns(Exception) as info:
         c2 = yield Client(processes=False, silence_logs=False, dashboard_address=9876)
 
-    assert 'bokeh' in c1.cluster.scheduler.services
-    assert 'bokeh' in c2.cluster.scheduler.services
+    assert "bokeh" in c1.cluster.scheduler.services
+    assert "bokeh" in c2.cluster.scheduler.services
 
-    assert any(all(word in str(msg.message).lower()
-                   for word in ['9876', 'running', 'already in use'])
-               for msg in info.list)
+    assert any(
+        all(
+            word in str(msg.message).lower()
+            for word in ["9876", "running", "already in use"]
+        )
+        for msg in info.list
+    )
     yield c1.close()
 
 
@@ -173,7 +210,7 @@ def test_Client_kwargs(loop):
     with Client(loop=loop, processes=False, n_workers=2, silence_logs=False) as c:
         assert len(c.cluster.workers) == 2
         assert all(isinstance(w, Worker) for w in c.cluster.workers)
-    assert c.cluster.status == 'closed'
+    assert c.cluster.status == "closed"
 
 
 def test_Client_twice(loop):
@@ -182,23 +219,26 @@ def test_Client_twice(loop):
             assert c.cluster.scheduler.port != f.cluster.scheduler.port
 
 
-@pytest.mark.skipif('sys.version_info[0] == 2', reason='fork issues')
+@pytest.mark.skipif("sys.version_info[0] == 2", reason="fork issues")
 def test_defaults():
     from distributed.worker import _ncores
 
-    with LocalCluster(scheduler_port=0, silence_logs=False,
-                      dashboard_address=None) as c:
+    with LocalCluster(
+        scheduler_port=0, silence_logs=False, dashboard_address=None
+    ) as c:
         assert sum(w.ncores for w in c.workers) == _ncores
         assert all(isinstance(w, Nanny) for w in c.workers)
 
-    with LocalCluster(processes=False, scheduler_port=0, silence_logs=False,
-                      dashboard_address=None) as c:
+    with LocalCluster(
+        processes=False, scheduler_port=0, silence_logs=False, dashboard_address=None
+    ) as c:
         assert sum(w.ncores for w in c.workers) == _ncores
         assert all(isinstance(w, Worker) for w in c.workers)
         assert len(c.workers) == 1
 
-    with LocalCluster(n_workers=2, scheduler_port=0, silence_logs=False,
-                      dashboard_address=None) as c:
+    with LocalCluster(
+        n_workers=2, scheduler_port=0, silence_logs=False, dashboard_address=None
+    ) as c:
         if _ncores % 2 == 0:
             expected_total_threads = max(2, _ncores)
         else:
@@ -206,60 +246,91 @@ def test_defaults():
             expected_total_threads = max(2, _ncores + 1)
         assert sum(w.ncores for w in c.workers) == expected_total_threads
 
-    with LocalCluster(threads_per_worker=_ncores * 2, scheduler_port=0,
-                      silence_logs=False, dashboard_address=None) as c:
+    with LocalCluster(
+        threads_per_worker=_ncores * 2,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+    ) as c:
         assert len(c.workers) == 1
 
-    with LocalCluster(n_workers=_ncores * 2, scheduler_port=0,
-                      silence_logs=False, dashboard_address=None) as c:
+    with LocalCluster(
+        n_workers=_ncores * 2,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+    ) as c:
         assert all(w.ncores == 1 for w in c.workers)
-    with LocalCluster(threads_per_worker=2, n_workers=3, scheduler_port=0,
-                      silence_logs=False, dashboard_address=None) as c:
+    with LocalCluster(
+        threads_per_worker=2,
+        n_workers=3,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+    ) as c:
         assert len(c.workers) == 3
         assert all(w.ncores == 2 for w in c.workers)
 
 
 def test_worker_params():
-    with LocalCluster(n_workers=2, scheduler_port=0, silence_logs=False,
-                      dashboard_address=None, memory_limit=500) as c:
+    with LocalCluster(
+        n_workers=2,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+        memory_limit=500,
+    ) as c:
         assert [w.memory_limit for w in c.workers] == [500] * 2
 
 
 def test_memory_limit_none():
-    with LocalCluster(n_workers=2, scheduler_port=0, silence_logs=False,
-                      processes=False,  dashboard_address=None, memory_limit=None) as c:
+    with LocalCluster(
+        n_workers=2,
+        scheduler_port=0,
+        silence_logs=False,
+        processes=False,
+        dashboard_address=None,
+        memory_limit=None,
+    ) as c:
         w = c.workers[0]
         assert type(w.data) is dict
         assert w.memory_limit is None
 
 
 def test_cleanup():
-    c = LocalCluster(2, scheduler_port=0, silence_logs=False,
-                     dashboard_address=None)
+    c = LocalCluster(2, scheduler_port=0, silence_logs=False, dashboard_address=None)
     port = c.scheduler.port
     c.close()
-    c2 = LocalCluster(2, scheduler_port=port, silence_logs=False,
-                      dashboard_address=None)
+    c2 = LocalCluster(
+        2, scheduler_port=port, silence_logs=False, dashboard_address=None
+    )
     c.close()
 
 
 def test_repeated():
-    with LocalCluster(scheduler_port=8448, silence_logs=False,
-                      dashboard_address=None) as c:
+    with LocalCluster(
+        scheduler_port=8448, silence_logs=False, dashboard_address=None
+    ) as c:
         pass
-    with LocalCluster(scheduler_port=8448, silence_logs=False,
-                      dashboard_address=None) as c:
+    with LocalCluster(
+        scheduler_port=8448, silence_logs=False, dashboard_address=None
+    ) as c:
         pass
 
 
-@pytest.mark.parametrize('processes', [True, False])
+@pytest.mark.parametrize("processes", [True, False])
 def test_bokeh(loop, processes):
-    pytest.importorskip('bokeh')
-    requests = pytest.importorskip('requests')
-    with LocalCluster(scheduler_port=0, silence_logs=False, loop=loop,
-                      processes=processes, dashboard_address=0) as c:
-        bokeh_port = c.scheduler.services['bokeh'].port
-        url = 'http://127.0.0.1:%d/status/' % bokeh_port
+    pytest.importorskip("bokeh")
+    requests = pytest.importorskip("requests")
+    with LocalCluster(
+        scheduler_port=0,
+        silence_logs=False,
+        loop=loop,
+        processes=processes,
+        dashboard_address=0,
+    ) as c:
+        bokeh_port = c.scheduler.services["bokeh"].port
+        url = "http://127.0.0.1:%d/status/" % bokeh_port
         start = time()
         while True:
             response = requests.get(url)
@@ -268,14 +339,14 @@ def test_bokeh(loop, processes):
             assert time() < start + 20
             sleep(0.01)
         # 'localhost' also works
-        response = requests.get('http://localhost:%d/status/' % bokeh_port)
+        response = requests.get("http://localhost:%d/status/" % bokeh_port)
         assert response.ok
 
     with pytest.raises(requests.RequestException):
         requests.get(url, timeout=0.2)
 
 
-@pytest.mark.skipif(sys.version_info < (3, 6), reason='Unknown')
+@pytest.mark.skipif(sys.version_info < (3, 6), reason="Unknown")
 def test_blocks_until_full(loop):
     with Client(loop=loop) as c:
         assert len(c.ncores()) > 0
@@ -284,9 +355,15 @@ def test_blocks_until_full(loop):
 @gen_test()
 def test_scale_up_and_down():
     loop = IOLoop.current()
-    cluster = yield LocalCluster(0, scheduler_port=0, processes=False,
-                                 silence_logs=False, dashboard_address=None,
-                                 loop=loop, asynchronous=True)
+    cluster = yield LocalCluster(
+        0,
+        scheduler_port=0,
+        processes=False,
+        silence_logs=False,
+        dashboard_address=None,
+        loop=loop,
+        asynchronous=True,
+    )
     c = yield Client(cluster, asynchronous=True)
 
     assert not cluster.workers
@@ -314,8 +391,9 @@ def test_silent_startup():
             sleep(1.5)
         """
 
-    out = subprocess.check_output([sys.executable, "-Wi", "-c", code],
-                                  stderr=subprocess.STDOUT)
+    out = subprocess.check_output(
+        [sys.executable, "-Wi", "-c", code], stderr=subprocess.STDOUT
+    )
     out = out.decode()
     try:
         assert not out
@@ -326,51 +404,74 @@ def test_silent_startup():
 
 
 def test_only_local_access(loop):
-    with LocalCluster(scheduler_port=0, silence_logs=False,
-                      dashboard_address=None, loop=loop) as c:
+    with LocalCluster(
+        scheduler_port=0, silence_logs=False, dashboard_address=None, loop=loop
+    ) as c:
         sync(loop, assert_can_connect_locally_4, c.scheduler.port)
 
 
 def test_remote_access(loop):
-    with LocalCluster(scheduler_port=0, silence_logs=False,
-                      dashboard_address=None, ip='', loop=loop) as c:
+    with LocalCluster(
+        scheduler_port=0, silence_logs=False, dashboard_address=None, ip="", loop=loop
+    ) as c:
         sync(loop, assert_can_connect_from_everywhere_4_6, c.scheduler.port)
 
 
-@pytest.mark.parametrize('n_workers', [None, 3])
+@pytest.mark.parametrize("n_workers", [None, 3])
 def test_memory(loop, n_workers):
-    with LocalCluster(n_workers=n_workers, scheduler_port=0, processes=False,
-                      silence_logs=False, dashboard_address=None, loop=loop) as cluster:
+    with LocalCluster(
+        n_workers=n_workers,
+        scheduler_port=0,
+        processes=False,
+        silence_logs=False,
+        dashboard_address=None,
+        loop=loop,
+    ) as cluster:
         assert sum(w.memory_limit for w in cluster.workers) <= TOTAL_MEMORY
 
 
-@pytest.mark.parametrize('n_workers', [None, 3])
+@pytest.mark.parametrize("n_workers", [None, 3])
 def test_memory_nanny(loop, n_workers):
-    with LocalCluster(n_workers=n_workers, scheduler_port=0, processes=True,
-                      silence_logs=False, dashboard_address=None, loop=loop) as cluster:
+    with LocalCluster(
+        n_workers=n_workers,
+        scheduler_port=0,
+        processes=True,
+        silence_logs=False,
+        dashboard_address=None,
+        loop=loop,
+    ) as cluster:
         with Client(cluster.scheduler_address, loop=loop) as c:
             info = c.scheduler_info()
-            assert (sum(w['memory_limit'] for w in info['workers'].values())
-                    <= TOTAL_MEMORY)
+            assert (
+                sum(w["memory_limit"] for w in info["workers"].values()) <= TOTAL_MEMORY
+            )
 
 
 def test_death_timeout_raises(loop):
     with pytest.raises(gen.TimeoutError):
-        with LocalCluster(scheduler_port=0, silence_logs=False,
-                          death_timeout=1e-10, dashboard_address=None,
-                          loop=loop) as cluster:
+        with LocalCluster(
+            scheduler_port=0,
+            silence_logs=False,
+            death_timeout=1e-10,
+            dashboard_address=None,
+            loop=loop,
+        ) as cluster:
             pass
 
 
-@pytest.mark.skipif(sys.version_info < (3, 6), reason='Unknown')
+@pytest.mark.skipif(sys.version_info < (3, 6), reason="Unknown")
 def test_bokeh_kwargs(loop):
-    pytest.importorskip('bokeh')
-    with LocalCluster(scheduler_port=0, silence_logs=False, loop=loop,
-                      dashboard_address=0,
-                      service_kwargs={'bokeh': {'prefix': '/foo'}}) as c:
+    pytest.importorskip("bokeh")
+    with LocalCluster(
+        scheduler_port=0,
+        silence_logs=False,
+        loop=loop,
+        dashboard_address=0,
+        service_kwargs={"bokeh": {"prefix": "/foo"}},
+    ) as c:
 
-        bs = c.scheduler.services['bokeh']
-        assert bs.prefix == '/foo'
+        bs = c.scheduler.services["bokeh"]
+        assert bs.prefix == "/foo"
 
 
 def test_io_loop_periodic_callbacks(loop):
@@ -393,9 +494,14 @@ def test_logging():
 
 
 def test_ipywidgets(loop):
-    ipywidgets = pytest.importorskip('ipywidgets')
-    with LocalCluster(scheduler_port=0, silence_logs=False, loop=loop,
-                      dashboard_address=False, processes=False) as cluster:
+    ipywidgets = pytest.importorskip("ipywidgets")
+    with LocalCluster(
+        scheduler_port=0,
+        silence_logs=False,
+        loop=loop,
+        dashboard_address=False,
+        processes=False,
+    ) as cluster:
         cluster._ipython_display_()
         box = cluster._cached_widget
         assert isinstance(box, ipywidgets.Widget)
@@ -403,8 +509,14 @@ def test_ipywidgets(loop):
 
 def test_scale(loop):
     """ Directly calling scale both up and down works as expected """
-    with LocalCluster(scheduler_port=0, silence_logs=False, loop=loop,
-                      dashboard_address=False, processes=False, n_workers=0) as cluster:
+    with LocalCluster(
+        scheduler_port=0,
+        silence_logs=False,
+        loop=loop,
+        dashboard_address=False,
+        processes=False,
+        n_workers=0,
+    ) as cluster:
         assert not cluster.scheduler.workers
         cluster.scale(3)
 
@@ -424,14 +536,20 @@ def test_scale(loop):
 
 
 def test_adapt(loop):
-    with LocalCluster(scheduler_port=0, silence_logs=False, loop=loop,
-                      dashboard_address=False, processes=False, n_workers=0) as cluster:
-        cluster.adapt(minimum=0, maximum=2, interval='10ms')
+    with LocalCluster(
+        scheduler_port=0,
+        silence_logs=False,
+        loop=loop,
+        dashboard_address=False,
+        processes=False,
+        n_workers=0,
+    ) as cluster:
+        cluster.adapt(minimum=0, maximum=2, interval="10ms")
         assert cluster._adaptive.minimum == 0
         assert cluster._adaptive.maximum == 2
         ref = weakref.ref(cluster._adaptive)
 
-        cluster.adapt(minimum=1, maximum=2, interval='10ms')
+        cluster.adapt(minimum=1, maximum=2, interval="10ms")
         assert cluster._adaptive.minimum == 1
         gc.collect()
 
@@ -450,10 +568,16 @@ def test_adapt(loop):
 
 def test_adapt_then_manual(loop):
     """ We can revert from adaptive, back to manual """
-    with LocalCluster(scheduler_port=0, silence_logs=False, loop=loop,
-                      dashboard_address=False, processes=False, n_workers=8) as cluster:
+    with LocalCluster(
+        scheduler_port=0,
+        silence_logs=False,
+        loop=loop,
+        dashboard_address=False,
+        processes=False,
+        n_workers=8,
+    ) as cluster:
         sleep(0.1)
-        cluster.adapt(minimum=0, maximum=4, interval='10ms')
+        cluster.adapt(minimum=0, maximum=4, interval="10ms")
 
         start = time()
         while cluster.scheduler.workers or cluster.workers:
@@ -480,19 +604,33 @@ def test_adapt_then_manual(loop):
 
 def test_local_tls(loop):
     from distributed.utils_test import tls_only_security
+
     security = tls_only_security()
-    with LocalCluster(scheduler_port=8786, silence_logs=False, security=security,
-                      dashboard_address=False, ip='tls://0.0.0.0', loop=loop) as c:
-        sync(loop, assert_can_connect_from_everywhere_4, c.scheduler.port,
-             connection_args=security.get_connection_args('client'),
-             protocol='tls', timeout=3)
+    with LocalCluster(
+        scheduler_port=8786,
+        silence_logs=False,
+        security=security,
+        dashboard_address=False,
+        ip="tls://0.0.0.0",
+        loop=loop,
+    ) as c:
+        sync(
+            loop,
+            assert_can_connect_from_everywhere_4,
+            c.scheduler.port,
+            connection_args=security.get_connection_args("client"),
+            protocol="tls",
+            timeout=3,
+        )
 
         # If we connect to a TLS localculster without ssl information we should fail
-        sync(loop, assert_cannot_connect,
-             addr='tcp://127.0.0.1:%d' % c.scheduler.port,
-             connection_args=security.get_connection_args('client'),
-             exception_class=RuntimeError,
-             )
+        sync(
+            loop,
+            assert_cannot_connect,
+            addr="tcp://127.0.0.1:%d" % c.scheduler.port,
+            connection_args=security.get_connection_args("client"),
+            exception_class=RuntimeError,
+        )
 
 
 @gen_test()
@@ -502,9 +640,15 @@ def test_scale_retires_workers():
             pass
 
     loop = IOLoop.current()
-    cluster = yield MyCluster(0, scheduler_port=0, processes=False,
-                              silence_logs=False, dashboard_address=None,
-                              loop=loop, asynchronous=True)
+    cluster = yield MyCluster(
+        0,
+        scheduler_port=0,
+        processes=False,
+        silence_logs=False,
+        dashboard_address=None,
+        loop=loop,
+        asynchronous=True,
+    )
     c = yield Client(cluster, asynchronous=True)
 
     assert not cluster.workers
@@ -529,15 +673,23 @@ def test_scale_retires_workers():
 
 def test_local_tls_restart(loop):
     from distributed.utils_test import tls_only_security
+
     security = tls_only_security()
-    with LocalCluster(n_workers=1, scheduler_port=8786, silence_logs=False, security=security,
-                      dashboard_address=False, ip='tls://0.0.0.0', loop=loop) as c:
+    with LocalCluster(
+        n_workers=1,
+        scheduler_port=8786,
+        silence_logs=False,
+        security=security,
+        dashboard_address=False,
+        ip="tls://0.0.0.0",
+        loop=loop,
+    ) as c:
         with Client(c.scheduler.address, loop=loop, security=security) as client:
             print(c.workers, c.workers[0].address)
-            workers_before = set(client.scheduler_info()['workers'])
+            workers_before = set(client.scheduler_info()["workers"])
             assert client.submit(inc, 1).result() == 2
             client.restart()
-            workers_after = set(client.scheduler_info()['workers'])
+            workers_after = set(client.scheduler_info()["workers"])
             assert client.submit(inc, 2).result() == 3
             assert workers_before != workers_after
 
@@ -556,8 +708,14 @@ def test_default_process_thread_breakdown():
 
 
 def test_asynchronous_property(loop):
-    with LocalCluster(4, scheduler_port=0, processes=False, silence_logs=False,
-                      dashboard_address=None, loop=loop) as cluster:
+    with LocalCluster(
+        4,
+        scheduler_port=0,
+        processes=False,
+        silence_logs=False,
+        dashboard_address=None,
+        loop=loop,
+    ) as cluster:
 
         @gen.coroutine
         def _():
@@ -567,20 +725,51 @@ def test_asynchronous_property(loop):
 
 
 def test_protocol_inproc(loop):
-    with LocalCluster(protocol='inproc://', loop=loop, processes=False) as cluster:
-        assert cluster.scheduler.address.startswith('inproc://')
+    with LocalCluster(protocol="inproc://", loop=loop, processes=False) as cluster:
+        assert cluster.scheduler.address.startswith("inproc://")
 
 
 def test_protocol_tcp(loop):
-    with LocalCluster(protocol='tcp', loop=loop, processes=False) as cluster:
-        assert cluster.scheduler.address.startswith('tcp://')
+    with LocalCluster(protocol="tcp", loop=loop, processes=False) as cluster:
+        assert cluster.scheduler.address.startswith("tcp://")
 
 
-@pytest.mark.skipif(not sys.platform.startswith('linux'),
-                    reason="Need 127.0.0.2 to mean localhost")
+@pytest.mark.skipif(
+    not sys.platform.startswith("linux"), reason="Need 127.0.0.2 to mean localhost"
+)
 def test_protocol_ip(loop):
-    with LocalCluster(ip='tcp://127.0.0.2', loop=loop, processes=False) as cluster:
-        assert cluster.scheduler.address.startswith('tcp://127.0.0.2')
+    with LocalCluster(ip="tcp://127.0.0.2", loop=loop, processes=False) as cluster:
+        assert cluster.scheduler.address.startswith("tcp://127.0.0.2")
+
+
+class MyWorker(Worker):
+    pass
+
+
+def test_worker_class_worker(loop):
+    with LocalCluster(
+        n_workers=2,
+        loop=loop,
+        worker_class=MyWorker,
+        processes=False,
+        scheduler_port=0,
+        dashboard_address=None,
+    ) as cluster:
+        assert all(isinstance(w, MyWorker) for w in cluster.workers)
+
+
+def test_worker_class_nanny(loop):
+    class MyNanny(Nanny):
+        pass
+
+    with LocalCluster(
+        n_workers=2,
+        loop=loop,
+        worker_class=MyNanny,
+        scheduler_port=0,
+        dashboard_address=None,
+    ) as cluster:
+        assert all(isinstance(w, MyNanny) for w in cluster.workers)
 
 
 if sys.version_info >= (3, 5):
